#[repr(i32)]pub enum ExtMemberRole {
Unspecified = 0,
Admin = 1,
Member = 2,
}Variants
Implementations
Sourceimpl ExtMemberRole
impl ExtMemberRole
Sourceimpl ExtMemberRole
impl ExtMemberRole
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.