pub struct CreateSendRequestResp {
pub id: String,
pub status: i32,
pub total_recipients: i32,
pub created_at: Option<Timestamp>,
}Fields
id: Stringstatus: i32total_recipients: i32created_at: Option<Timestamp>Implementations
Sourceimpl CreateSendRequestResp
impl CreateSendRequestResp
Sourcepub fn status(&self) -> SendRequestStatus
pub fn status(&self) -> SendRequestStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SendRequestStatus)
pub fn set_status(&mut self, value: SendRequestStatus)
Sets status to the provided enum value.