ExtAddMemberReq

Struct ExtAddMemberReq 

pub struct ExtAddMemberReq {
    pub channel_id: String,
    pub ppnum: String,
    pub role: i32,
}

Fields

channel_id: Stringppnum: Stringrole: i32

Default: MEMBER if unspecified

Implementations

Source

impl ExtAddMemberReq

pub fn role(&self) -> ExtMemberRole

Returns the enum value of role, or the default if the field is set to an invalid enum value.

pub fn set_role(&mut self, value: ExtMemberRole)

Sets role to the provided enum value.