pub struct ExtCreateChannelReq {
pub name: String,
pub type: i32,
pub storage_mode: i32,
pub retention_days: Option<u32>,
pub ttl_secs: Option<i32>,
pub members: Vec<ExtInitialMember>,
}Fields
name: Stringtype: i32storage_mode: i32retention_days: Option<u32>ttl_secs: Option<i32>members: Vec<ExtInitialMember>Members with explicit roles (replaces member_ppnums)
Implementations
Sourceimpl ExtCreateChannelReq
impl ExtCreateChannelReq
Sourcepub fn type(&self) -> ExtChannelType
pub fn type(&self) -> ExtChannelType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ExtChannelType)
pub fn set_type(&mut self, value: ExtChannelType)
Sets type to the provided enum value.
Sourcepub fn storage_mode(&self) -> ExtStorageMode
pub fn storage_mode(&self) -> ExtStorageMode
Returns the enum value of storage_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_storage_mode(&mut self, value: ExtStorageMode)
pub fn set_storage_mode(&mut self, value: ExtStorageMode)
Sets storage_mode to the provided enum value.
Sourcepub fn retention_days(&self) -> u32
pub fn retention_days(&self) -> u32
Returns the value of retention_days, or the default value if retention_days is unset.