pub struct ExtGetChannelResp {
pub channel_id: String,
pub name: String,
pub type: i32,
pub storage_mode: i32,
pub member_count: i32,
pub last_message_at: Option<Timestamp>,
pub created_at: Option<Timestamp>,
}Fields
channel_id: Stringname: Stringtype: i32storage_mode: i32member_count: i32last_message_at: Option<Timestamp>created_at: Option<Timestamp>Implementations
Sourceimpl ExtGetChannelResp
impl ExtGetChannelResp
Sourcepub fn type(&self) -> ExtChannelType
pub fn type(&self) -> ExtChannelType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ExtChannelType)
pub fn set_type(&mut self, value: ExtChannelType)
Sets type to the provided enum value.
Sourcepub fn storage_mode(&self) -> ExtStorageMode
pub fn storage_mode(&self) -> ExtStorageMode
Returns the enum value of storage_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_storage_mode(&mut self, value: ExtStorageMode)
pub fn set_storage_mode(&mut self, value: ExtStorageMode)
Sets storage_mode to the provided enum value.