pub struct ExtInitialMember {
pub ppnum: String,
pub role: i32,
}Expand description
Initial member with explicit role assignment
Fields
ppnum: Stringrole: i32ADMIN or MEMBER — no default, caller must specify
Implementations
Sourceimpl ExtInitialMember
impl ExtInitialMember
Sourcepub fn role(&self) -> ExtMemberRole
pub fn role(&self) -> ExtMemberRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: ExtMemberRole)
pub fn set_role(&mut self, value: ExtMemberRole)
Sets role to the provided enum value.