pub struct ExtMemberInfo {
pub ppnum: String,
pub role: i32,
pub joined_at: Option<Timestamp>,
}Fields
ppnum: Stringrole: i32joined_at: Option<Timestamp>Implementations
Sourceimpl ExtMemberInfo
impl ExtMemberInfo
Sourcepub fn role(&self) -> ExtMemberRole
pub fn role(&self) -> ExtMemberRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: ExtMemberRole)
pub fn set_role(&mut self, value: ExtMemberRole)
Sets role to the provided enum value.