pub struct GetUsageStatsResp {
pub app_id: String,
pub tier: i32,
pub monthly_message_limit: Option<i32>,
pub current_month_usage: i32,
pub remaining_quota: Option<i32>,
pub usage_reset_at: Option<Timestamp>,
pub rate_limit_per_min: i32,
pub system_ppnum: String,
}Fields
app_id: Stringtier: i32monthly_message_limit: Option<i32>current_month_usage: i32remaining_quota: Option<i32>usage_reset_at: Option<Timestamp>rate_limit_per_min: i32system_ppnum: String발신자 ppnum (11자리, e.g. “50001234567”)
Implementations
Sourceimpl GetUsageStatsResp
impl GetUsageStatsResp
Sourcepub fn tier(&self) -> AppTier
pub fn tier(&self) -> AppTier
Returns the enum value of tier, or the default if the field is set to an invalid enum value.
Sourcepub fn monthly_message_limit(&self) -> i32
pub fn monthly_message_limit(&self) -> i32
Returns the value of monthly_message_limit, or the default value if monthly_message_limit is unset.
Sourcepub fn remaining_quota(&self) -> i32
pub fn remaining_quota(&self) -> i32
Returns the value of remaining_quota, or the default value if remaining_quota is unset.