pub struct RecipientStatus {
pub id: String,
pub ppnum: String,
pub status: i32,
pub message_id: Option<String>,
pub error_code: Option<String>,
pub created_at: Option<Timestamp>,
}Fields
id: Stringppnum: Stringstatus: i32message_id: Option<String>error_code: Option<String>created_at: Option<Timestamp>Implementations
Sourceimpl RecipientStatus
impl RecipientStatus
Sourcepub fn status(&self) -> RecipientDeliveryStatus
pub fn status(&self) -> RecipientDeliveryStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: RecipientDeliveryStatus)
pub fn set_status(&mut self, value: RecipientDeliveryStatus)
Sets status to the provided enum value.
Sourcepub fn message_id(&self) -> &str
pub fn message_id(&self) -> &str
Returns the value of message_id, or the default value if message_id is unset.
Sourcepub fn error_code(&self) -> &str
pub fn error_code(&self) -> &str
Returns the value of error_code, or the default value if error_code is unset.