pub struct SendRequestSummary {
pub id: String,
pub status: i32,
pub total_recipients: i32,
pub delivered: i32,
pub pending_consent: i32,
pub failed: i32,
pub created_at: Option<Timestamp>,
pub completed_at: Option<Timestamp>,
}Fields
id: Stringstatus: i32total_recipients: i32delivered: i32pending_consent: i32failed: i32created_at: Option<Timestamp>completed_at: Option<Timestamp>Implementations
Sourceimpl SendRequestSummary
impl SendRequestSummary
Sourcepub fn status(&self) -> SendRequestStatus
pub fn status(&self) -> SendRequestStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SendRequestStatus)
pub fn set_status(&mut self, value: SendRequestStatus)
Sets status to the provided enum value.