TemplateComponent

Struct TemplateComponent 

pub struct TemplateComponent {
    pub component_type: i32,
    pub content: Option<String>,
    pub label: Option<String>,
    pub url: Option<String>,
    pub alt: Option<String>,
    pub question: Option<String>,
    pub options: Vec<String>,
}

Fields

component_type: i32content: Option<String>

Text content

label: Option<String>

Button label

url: Option<String>

Button URL or Image URL

alt: Option<String>

Image alt text

question: Option<String>

Poll question

options: Vec<String>

Poll options

Implementations

Source

impl TemplateComponent

pub fn component_type(&self) -> TemplateComponentType

Returns the enum value of component_type, or the default if the field is set to an invalid enum value.

pub fn set_component_type(&mut self, value: TemplateComponentType)

Sets component_type to the provided enum value.

pub fn content(&self) -> &str

Returns the value of content, or the default value if content is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn url(&self) -> &str

Returns the value of url, or the default value if url is unset.

pub fn alt(&self) -> &str

Returns the value of alt, or the default value if alt is unset.

pub fn question(&self) -> &str

Returns the value of question, or the default value if question is unset.