pub struct ExtMessageInfo {
pub id: String,
pub sender_ppnum: String,
pub content: String,
pub type: i32,
pub parent_message_id: Option<String>,
pub created_at: Option<Timestamp>,
}Fields
id: Stringsender_ppnum: Stringcontent: Stringtype: i32parent_message_id: Option<String>created_at: Option<Timestamp>Implementations
Sourceimpl ExtMessageInfo
impl ExtMessageInfo
Sourcepub fn type(&self) -> ExtMessageType
pub fn type(&self) -> ExtMessageType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ExtMessageType)
pub fn set_type(&mut self, value: ExtMessageType)
Sets type to the provided enum value.
Sourcepub fn parent_message_id(&self) -> &str
pub fn parent_message_id(&self) -> &str
Returns the value of parent_message_id, or the default value if parent_message_id is unset.